@@ -4,6 +4,6 @@ Pyinter is a python interval library which deals with interval arithmetic and se
 
 from pyinter.interval import Interval, open, closed, openclosed, closedopen
 from pyinter.interval_set import IntervalSet
-from . import examples
+from pyinter import examples
 
 __all__ = [Interval, open, closed, openclosed, closedopen, IntervalSet, examples]
